/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package top.continew.admin.business.service.Impl;

import cn.dev33.satoken.stp.StpUtil;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import top.continew.admin.business.model.entity.TgUser;
import top.continew.admin.business.model.req.AirdropManagerReq;
import top.continew.admin.business.mq.AirdropMessageProducer;
import top.continew.admin.business.service.AirdropManagerService;
import top.continew.admin.business.service.IAirdropRecordService;
import top.continew.admin.business.service.ITgUserService;
import top.continew.starter.core.validation.CheckUtils;

@Service
@AllArgsConstructor
@Slf4j
public class AirdropManagerServiceImpl implements AirdropManagerService {
    private final IAirdropRecordService recordService;
    private final ITgUserService userService;

    private AirdropMessageProducer airdropMessageProducer;

    @Override
    @Transactional
    public void airdropManager(AirdropManagerReq req) {
        Object loginId = StpUtil.getLoginId();
        TgUser user = userService.getById(req.getTargetUser());
        CheckUtils.throwIfNull(user, "空投目标用户为空");

        req.setOperationUser(String.valueOf(loginId));
        //使用队列的方式进行异步处理 在app端进行异步处理
        airdropMessageProducer.sendMessage(req);
    }
}
